@@ -42,7 +42,7 @@ class __TwigTemplate_ccc3f72ab858d105a4306f762fae357a extends Template
         // line 1
         yield "<!DOCTYPE html>
 <html>
-";
+    ";
         // line 3
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Default/head.html.twig", ["headerTitle" => ((        $this->unwrap()->hasBlock("headerTitle", $context, $blocks)) ? (        $this->unwrap()->renderBlock("headerTitle", $context, $blocks)) : (((        // line 4
 array_key_exists("headerTitle", $context)) ? (Twig\Extension\CoreExtension::default((isset($context["headerTitle"]) || array_key_exists("headerTitle", $context) ? $context["headerTitle"] : (function () { throw new RuntimeError('Variable "headerTitle" does not exist.', 4, $this->source); })()), "")) : ("")))), "pageTitle" => ((        $this->unwrap()->hasBlock("pageTitle", $context, $blocks)) ? ("Cause Buzz") : ("Cause Buzz"))]);
@@ -140,69 +140,63 @@ array_key_exists("headerTitle", $context)) ? (Twig\Extension\CoreExtension::defa
         // line 59
         yield "            </script>
             <script>
-                (function () {
-                    // prevent double-install (avoids breaking pages)
-                    if (window.__causeBuzzTitlePatchInstalled) return;
-                    window.__causeBuzzTitlePatchInstalled = true;
-
+                (function() {
                     const BRAND = 'Cause Buzz';
 
-                    function normalizeTitle() {
-                        try {
-                            let t = (document.title || '').trim();
+                    function applyTitle() {
+                        let t = document.title.trim();
 
-                            // remove trailing \"| Mautic\"
-                            t = t.replace(/\\s*\\|\\s*Mautic\\s*\$/i, '').trim();
+                        // If Mautic sets \"Something | Mautic\", replace that part
+                        if (t.endsWith('| Mautic')) {
+                            t = t.replace(/\\|\\s*Mautic\$/, '| ' + BRAND);
+                            document.title = t;
+                            return;
+                        }
 
-                            // if title is empty or exactly \"Mautic\", just use the brand
-                            if (!t || /^Mautic\$/i.test(t)) {
-                                document.title = BRAND;
-                                return;
-                            }
-
-                            // avoid \"Cause Buzz | Cause Buzz\"
-                            if (new RegExp('^' + BRAND.replace(/[.*+?^\${}()|[\\]\\\\]/g, '\\\\\$&') + '\\\\s*\\\\|\\\\s*' + BRAND + '\$', 'i').test(t)) {
-                                document.title = BRAND;
-                                return;
-                            }
-
-                            // avoid double appends
-                            if (new RegExp('\\\\|\\\\s*' + BRAND.replace(/[.*+?^\${}()|[\\]\\\\]/g, '\\\\\$&') + '\\\\s*\$', 'i').test(t)) {
-                                document.title = t;
-                                return;
-                            }
+                        // If the page only sets \"Mautic\" with no prefix
+                        if (t === 'Mautic') {
+                            document.title = BRAND;
+                            return;
+                        }
 
+                        // If no brand yet, append it
+                        if (!t.includes(BRAND)) {
                             document.title = t + ' | ' + BRAND;
-                        } catch (e) {
-                            // swallow errors so we never break the UI
                         }
                     }
 
-                    function scheduleNormalize() {
-                        // run after Mautic has finished its SPA title update
-                        setTimeout(normalizeTitle, 0);
+                    // Run immediately
+                    applyTitle();
+
+                    // Watch for SPA title changes
+                    const titleEl = document.querySelector('title');
+                    if (titleEl) {
+                        new MutationObserver(applyTitle).observe(titleEl, { childList: true });
                     }
 
-                    // first load
-                    if (document.readyState === 'loading') {
-                        document.addEventListener('DOMContentLoaded', scheduleNormalize, { once: true });
-                    } else {
-                        scheduleNormalize();
+                    // Hook into Mautic's SPA navigation
+                    if (window.Mautic && typeof window.Mautic.onPageLoad === 'function') {
+                        const original = window.Mautic.onPageLoad;
+                        window.Mautic.onPageLoad = function(e) {
+                            original(e);
+                            applyTitle();
+                        };
                     }
 
-                    // SPA navigation hook
-                    document.addEventListener('mautic:page:load', scheduleNormalize);
+                    // Stimulus events also change title in Mautic 5
+                    document.addEventListener('stimulus:load', applyTitle);
+
                 })();
             </script>
 
             ";
-        // line 116
+        // line 110
         yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->outputScripts("bodyClose");
         yield "
             ";
-        // line 117
+        // line 111
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Helper/modal.html.twig", ["id" => "MauticSharedModal", "footerButtons" => true]);
-        // line 120
+        // line 114
         yield "
         </section>
     </body>
@@ -248,7 +242,7 @@ array_key_exists("headerTitle", $context)) ? (Twig\Extension\CoreExtension::defa
      */
     public function getDebugInfo(): array
     {
-        return array (  223 => 40,  216 => 39,  206 => 120,  204 => 117,  200 => 116,  141 => 59,  127 => 47,  125 => 46,  119 => 42,  117 => 39,  107 => 32,  103 => 31,  93 => 24,  86 => 20,  80 => 17,  76 => 16,  72 => 15,  68 => 14,  64 => 13,  60 => 12,  55 => 10,  50 => 7,  48 => 4,  47 => 3,  43 => 1,);
+        return array (  217 => 40,  210 => 39,  200 => 114,  198 => 111,  194 => 110,  141 => 59,  127 => 47,  125 => 46,  119 => 42,  117 => 39,  107 => 32,  103 => 31,  93 => 24,  86 => 20,  80 => 17,  76 => 16,  72 => 15,  68 => 14,  64 => 13,  60 => 12,  55 => 10,  50 => 7,  48 => 4,  47 => 3,  43 => 1,);
     }
 
     public function getSourceContext(): Source
